<a id="mypy-boto3-acm"></a>

# mypy-boto3-acm

[![PyPI - types-aiobotocore-acm](https://img.shields.io/pypi/v/types-aiobotocore-acm.svg?color=blue)](https://pypi.org/project/types-aiobotocore-acm)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/types-aiobotocore-acm.svg?color=blue)](https://pypi.org/project/types-aiobotocore-acm)
[![Docs](https://img.shields.io/readthedocs/mypy-boto3-builder.svg?color=blue)](https://mypy-boto3-builder.readthedocs.io/)
[![PyPI - Downloads](https://img.shields.io/pypi/dm/types-aiobotocore-acm?color=blue)](https://pypistats.org/packages/types-aiobotocore-acm)

![boto3.typed](https://github.com/vemel/mypy_boto3_builder/raw/main/logo.png)

Type annotations for
[boto3.ACM 1.20.47](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/acm.html#ACM)
service compatible with [VSCode](https://code.visualstudio.com/),
[PyCharm](https://www.jetbrains.com/pycharm/),
[Emacs](https://www.gnu.org/software/emacs/),
[Sublime Text](https://www.sublimetext.com/),
[mypy](https://github.com/python/mypy),
[pyright](https://github.com/microsoft/pyright) and other tools.

Generated by
[mypy-boto3-builder 6.4.2](https://github.com/vemel/mypy_boto3_builder).

More information can be found on
[boto3-stubs](https://pypi.org/project/boto3-stubs/) page and in
[types-aiobotocore-acm docs](https://vemel.github.io/types_aiobotocore_docs/types_aiobotocore_acm/)

See how it helps to find and fix potential bugs:

![boto3-stubs demo](https://github.com/vemel/mypy_boto3_builder/raw/main/demo.gif)

- [mypy-boto3-acm](#mypy-boto3-acm)
  - [How to install](#how-to-install)
    - [VSCode extension](#vscode-extension)
    - [From PyPI with pip](#from-pypi-with-pip)
  - [Usage](#usage)
    - [VSCode](#vscode)
    - [PyCharm](#pycharm)
    - [Other IDEs](#other-ides)
    - [mypy](#mypy)
    - [pyright](#pyright)
  - [Explicit type annotations](#explicit-type-annotations)
    - [Client annotations](#client-annotations)
    - [Paginators annotations](#paginators-annotations)
    - [Literals](#literals)
    - [Typed dictionaries](#typed-dictionaries)
  - [Versioning](#versioning)
  - [Documentation](#documentation)
  - [Support and contributing](#support-and-contributing)

<a id="how-to-install"></a>

## How to install

<a id="vscode-extension"></a>

### VSCode extension

Add
[AWS Boto3](https://marketplace.visualstudio.com/items?itemName=Boto3typed.boto3-ide)
extension to your VSCode and run `AWS boto3: Quick Start` command.

Click `Modify` and select `boto3 common` and `ACM`.

<a id="from-pypi-with-pip"></a>

### From PyPI with pip

Install `types-aiobotocore` for `ACM` service.

```bash
python -m pip install types-aiobotocore[acm]
```

<a id="usage"></a>

## Usage

<a id="vscode"></a>

### VSCode

- Install
  [Python extension](https://marketplace.visualstudio.com/items?itemName=ms-python.python)
- Install
  [Pylance extension](https://marketplace.visualstudio.com/items?itemName=ms-python.vscode-pylance)
- Set `Pylance` as your Python Language Server
- Install `types-aiobotocore[acm]` in your environment:
  `python -m pip install 'types-aiobotocore[acm]'`

Both type checking and auto-complete should work for `ACM` service. No explicit
type annotations required, write your `boto3` code as usual.

<a id="pycharm"></a>

### PyCharm

- Install `types-aiobotocore[acm]` in your environment:
  `python -m pip install 'types-aiobotocore[acm]'`

Both type checking and auto-complete should work for `ACM` service. No explicit
type annotations required, write your `aiobotocore` code as usual.
Auto-complete can be slow on big projects or if you have a lot of installed
`types-aiobotocore` submodules.

<a id="other-ides"></a>

### Other IDEs

Not tested, but as long as your IDE supports `mypy` or `pyright`, everything
should work.

<a id="mypy"></a>

### mypy

- Install `mypy`: `python -m pip install mypy`
- Install `types-aiobotocore[acm]` in your environment:
  `python -m pip install 'types-aiobotocore[acm]'`
- Run `mypy` as usual

Type checking should work for `ACM` service. No explicit type annotations
required, write your `aiobotocore` code as usual.

<a id="pyright"></a>

### pyright

- Install `pyright`: `yarn global add pyright`
- Install `types-aiobotocore[acm]` in your environment:
  `python -m pip install 'types-aiobotocore[acm]'`
- Optionally, you can install `boto3-stubs` to `typings` folder.

Type checking should work for `ACM` service. No explicit type annotations
required, write your `aiobotocore` code as usual.

<a id="explicit-type-annotations"></a>

## Explicit type annotations

<a id="client-annotations"></a>

### Client annotations

`ACMClient` provides annotations for `session.create_client("acm")`.

```python
from aiobotocore.session import get_session

from types_aiobotocore_acm import ACMClient

session = get_session()
with async session.create_client("acm") as client:
    client: ACMClient
    # now client usage is checked by mypy and IDE should provide code auto-complete
```

<a id="paginators-annotations"></a>

### Paginators annotations

`types_aiobotocore_acm.paginator` module contains type annotations for all
paginators.

````python
from aiobotocore.session import get_session

from types_aiobotocore_acm import ACMClient
from types_aiobotocore_acm.paginator import (
    ListCertificatesPaginator,
)

session = get_session()
with async session.create_client("acm") as client:
    client: ACMClient

    # Explicit type annotations are optional here
    # Type should be correctly discovered by mypy and IDEs
    # VSCode requires explicit type annotations
        list_certificates_paginator: ListCertificatesPaginator = client.get_paginator("list_certificates")
    ```


### Waiters annotations

`types_aiobotocore_acm.waiter` module contains type annotations for all waiters.

```python
from aiobotocore.session import get_session

from types_aiobotocore_acm.client import ACMClient
from types_aiobotocore_acm.waiter import (
    CertificateValidatedWaiter,
)

session = get_session()
with async session.create_client("acm") as client:
    client: ACMClient

    # Explicit type annotations are optional here
    # Type should be correctly discovered by mypy and IDEs
    # VSCode requires explicit type annotations
        certificate_validated_waiter: CertificateValidatedWaiter = client.get_waiter("certificate_validated")
    ```





<a id="literals"></a>

### Literals

`types_aiobotocore_acm.literals` module contains literals extracted from shapes
that can be used in user code for type checking.

```python
from types_aiobotocore_acm.literals import (
    CertificateStatusType,
    CertificateTransparencyLoggingPreferenceType,
    CertificateTypeType,
    CertificateValidatedWaiterName,
    DomainStatusType,
    ExtendedKeyUsageNameType,
    FailureReasonType,
    KeyAlgorithmType,
    KeyUsageNameType,
    ListCertificatesPaginatorName,
    RecordTypeType,
    RenewalEligibilityType,
    RenewalStatusType,
    RevocationReasonType,
    ValidationMethodType,
    ServiceName,
    PaginatorName,
    WaiterName,
)

def check_value(value: CertificateStatusType) -> bool:
    ...
````

<a id="typed-dictionaries"></a>

### Typed dictionaries

`types_aiobotocore_acm.type_defs` module contains structures and shapes
assembled to typed dictionaries for additional type checking.

```python
from types_aiobotocore_acm.type_defs import (
    AddTagsToCertificateRequestRequestTypeDef,
    CertificateDetailTypeDef,
    CertificateOptionsTypeDef,
    CertificateSummaryTypeDef,
    DeleteCertificateRequestRequestTypeDef,
    DescribeCertificateRequestRequestTypeDef,
    DescribeCertificateResponseTypeDef,
    DomainValidationOptionTypeDef,
    DomainValidationTypeDef,
    ExpiryEventsConfigurationTypeDef,
    ExportCertificateRequestRequestTypeDef,
    ExportCertificateResponseTypeDef,
    ExtendedKeyUsageTypeDef,
    FiltersTypeDef,
    GetAccountConfigurationResponseTypeDef,
    GetCertificateRequestRequestTypeDef,
    GetCertificateResponseTypeDef,
    ImportCertificateRequestRequestTypeDef,
    ImportCertificateResponseTypeDef,
    KeyUsageTypeDef,
    ListCertificatesRequestRequestTypeDef,
    ListCertificatesResponseTypeDef,
    ListTagsForCertificateRequestRequestTypeDef,
    ListTagsForCertificateResponseTypeDef,
    PaginatorConfigTypeDef,
    PutAccountConfigurationRequestRequestTypeDef,
    RemoveTagsFromCertificateRequestRequestTypeDef,
    RenewCertificateRequestRequestTypeDef,
    RenewalSummaryTypeDef,
    RequestCertificateRequestRequestTypeDef,
    RequestCertificateResponseTypeDef,
    ResendValidationEmailRequestRequestTypeDef,
    ResourceRecordTypeDef,
    ResponseMetadataTypeDef,
    TagTypeDef,
    UpdateCertificateOptionsRequestRequestTypeDef,
    WaiterConfigTypeDef,
)

def get_structure() -> AddTagsToCertificateRequestRequestTypeDef:
    return {
      ...
    }
```

<a id="versioning"></a>

## Versioning

`types-aiobotocore-acm` version is the same as related `boto3` version and
follows [PEP 440](https://www.python.org/dev/peps/pep-0440/) format.

<a id="documentation"></a>

## Documentation

All type annotations can be found in
[types-aiobotocore-acm docs](https://vemel.github.io/types_aiobotocore_docs/types_aiobotocore_acm/)

<a id="support-and-contributing"></a>

## Support and contributing

This package is auto-generated. Please reports any bugs or request new features
in [mypy-boto3-builder](https://github.com/vemel/mypy_boto3_builder/issues/)
repository.
